@@ -40,7 +40,6 @@
 #include <e-util/e-dialog-utils.h>
 #include "common/authentication.h"
 #include "../e-timezone-entry.h"
-#include "../calendar-config.h"
 #include "comp-editor.h"
 #include "comp-editor-util.h"
 #include "e-send-options-utils.h"
@@ -55,13 +54,6 @@
 #include "../e-meeting-store.h"
 #include "../e-meeting-list-view.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
-#define TASK_PAGE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), TYPE_TASK_PAGE, TaskPagePrivate))
-
 /* Private part of the TaskPage structure */
 struct _TaskPagePrivate {
 	GtkBuilder *builder;
@@ -156,7 +148,7 @@ task_page_dispose (GObject *object)
 {
 	TaskPagePrivate *priv;
 
-	priv = TASK_PAGE_GET_PRIVATE (object);
+	priv = TASK_PAGE (object)->priv;
 
 	if (priv->main != NULL) {
 		g_object_unref (priv->main);
@@ -187,7 +179,7 @@ task_page_finalize (GObject *object)
 {
 	TaskPagePrivate *priv;
 
-	priv = TASK_PAGE_GET_PRIVATE (object);
+	priv = TASK_PAGE (object)->priv;
 
 	g_list_foreach (priv->address_strings, (GFunc) g_free, NULL);
 	g_list_free (priv->address_strings);
@@ -225,7 +217,8 @@ task_page_class_init (TaskPageClass *class)
 static void
 task_page_init (TaskPage *tpage)
 {
-	tpage->priv = TASK_PAGE_GET_PRIVATE (tpage);
+	tpage->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		tpage, TYPE_TASK_PAGE, TaskPagePrivate);
 	tpage->priv->deleted_attendees = g_ptr_array_new ();
 }
 
@@ -588,7 +581,7 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	e_cal_component_free_text_list (l);
 	e_buffer_tagger_update_tags (GTK_TEXT_VIEW (priv->description));
 
-	default_zone = calendar_config_get_icaltimezone ();
+	default_zone = comp_editor_get_timezone (editor);
 
 	/* Due Date. */
 	e_cal_component_get_due (comp, &d);
@@ -733,8 +726,10 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 				g_signal_handlers_block_by_func (gtk_bin_get_child (GTK_BIN (priv->organizer)), organizer_changed_cb, tpage);
 
 				if (!priv->user_org) {
-					gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer))));
-					gtk_combo_box_append_text (GTK_COMBO_BOX (priv->organizer), string);
+					GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer));
+
+					gtk_list_store_clear (GTK_LIST_STORE (model));
+					e_dialog_append_list_store_text (model, 0, string);
 					gtk_combo_box_set_active (GTK_COMBO_BOX (priv->organizer), 0);
 					gtk_editable_set_editable (GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (priv->organizer))), FALSE);
 				} else {
@@ -938,8 +933,10 @@ task_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 	e_cal_component_set_classification (comp, classification);
 
 	/* send options */
-	if (priv->sendoptions_shown && priv->sod)
-		e_send_options_utils_fill_component (priv->sod, comp);
+	if (priv->sendoptions_shown && priv->sod) {
+		icaltimezone *zone = comp_editor_get_timezone (editor);
+		e_send_options_utils_fill_component (priv->sod, comp, zone);
+	}
 
 	/* Categories */
 	cat = e_dialog_editable_get (priv->categories);
@@ -1420,7 +1417,7 @@ get_widgets (TaskPage *tpage)
 
 	priv->organizer = e_builder_get_widget (priv->builder, "organizer");
 	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer))));
-	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (priv->organizer), 0);
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (priv->organizer), 0);
 
 	priv->invite = e_builder_get_widget (priv->builder, "invite");
 	priv->add = e_builder_get_widget (priv->builder, "add-attendee");
@@ -1726,7 +1723,7 @@ source_changed_cb (ESourceComboBox *source_combo_box, TaskPage *tpage)
 	if (client) {
 		icaltimezone *zone;
 
-		zone = calendar_config_get_icaltimezone ();
+		zone = comp_editor_get_timezone (editor);
 		e_cal_set_default_timezone (client, zone, NULL);
 	}
 
@@ -1842,12 +1839,16 @@ init_widgets (TaskPage *tpage)
 
 	/* Make sure the EDateEdit widgets use our timezones to get the
 	   current time. */
-	e_date_edit_set_get_time_callback (E_DATE_EDIT (priv->start_date),
-					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
-					   tpage, NULL);
-	e_date_edit_set_get_time_callback (E_DATE_EDIT (priv->due_date),
-					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
-					   tpage, NULL);
+	e_date_edit_set_get_time_callback (
+		E_DATE_EDIT (priv->start_date),
+		(EDateEditGetTimeCallback) comp_editor_get_current_time,
+		g_object_ref (editor),
+		(GDestroyNotify) g_object_unref);
+	e_date_edit_set_get_time_callback (
+		E_DATE_EDIT (priv->due_date),
+		(EDateEditGetTimeCallback) comp_editor_get_current_time,
+		g_object_ref (editor),
+		(GDestroyNotify) g_object_unref);
 
 	/* Generic informative messages */
 	gtk_widget_hide (priv->info_hbox);
@@ -1931,7 +1932,7 @@ init_widgets (TaskPage *tpage)
 	g_signal_connect (priv->list_view, "attendee_added", G_CALLBACK (attendee_added_cb), tpage);
 
 	/* Set the default timezone, so the timezone entry may be hidden. */
-	zone = calendar_config_get_icaltimezone ();
+	zone = comp_editor_get_timezone (editor);
 	e_timezone_entry_set_default_timezone (E_TIMEZONE_ENTRY (priv->timezone), zone);
 
 	action = comp_editor_get_action (editor, "view-time-zone");
@@ -2084,9 +2085,10 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 
 	if (priv->address_strings) {
 		GList *l;
+		GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer));
 
 		for (l = priv->address_strings; l; l = l->next)
-			gtk_combo_box_append_text (GTK_COMBO_BOX (priv->organizer), l->data);
+			e_dialog_append_list_store_text (model, 0, l->data);
 
 		gtk_combo_box_set_active (GTK_COMBO_BOX (priv->organizer), 0);
 
@@ -2147,9 +2149,10 @@ task_page_get_cancel_comp (TaskPage *page)
 
 /**
  * task_page_add_attendee
+ * @tpage: a #TaskPage
+ * @attendee: Attendee to be added.
+ *
  * Add attendee to meeting store and name selector.
- * @param tpage TaskPage.
- * @param attendee Attendee to be added.
  **/
 void
 task_page_add_attendee (TaskPage *tpage, EMeetingAttendee *attendee)
