@@ -61,10 +61,6 @@
 #include "goto.h"
 #include "misc.h"
 
-#define E_CALENDAR_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CALENDAR_VIEW, ECalendarViewPrivate))
-
 struct _ECalendarViewPrivate {
 	/* The GnomeCalendar we are associated to */
 	GnomeCalendar *calendar;
@@ -322,7 +318,7 @@ calendar_view_dispose (GObject *object)
 {
 	ECalendarViewPrivate *priv;
 
-	priv = E_CALENDAR_VIEW_GET_PRIVATE (object);
+	priv = E_CALENDAR_VIEW (object)->priv;
 
 	if (priv->model != NULL) {
 		g_signal_handlers_disconnect_matched (
@@ -351,7 +347,7 @@ calendar_view_finalize (GObject *object)
 {
 	ECalendarViewPrivate *priv;
 
-	priv = E_CALENDAR_VIEW_GET_PRIVATE (object);
+	priv = E_CALENDAR_VIEW (object)->priv;
 
 	g_free (priv->default_category);
 
@@ -917,7 +913,8 @@ e_calendar_view_init (ECalendarView *calendar_view)
 {
 	GtkTargetList *target_list;
 
-	calendar_view->priv = E_CALENDAR_VIEW_GET_PRIVATE (calendar_view);
+	calendar_view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		calendar_view, E_TYPE_CALENDAR_VIEW, ECalendarViewPrivate);
 
 	/* Set this early to avoid a divide-by-zero during init. */
 	calendar_view->priv->time_divisions = 30;
@@ -1501,10 +1498,11 @@ e_calendar_view_new_appointment_for (ECalendarView *cal_view,
 
 /**
  * e_calendar_view_new_appointment_full
- * @param cal_view: A calendar view.
- * @param all_day: Whether create all day event or not.
- * @param meeting: This is a meeting or an appointment.
- * @param no_past_date: Don't create event in past date, use actual date instead (if TRUE).
+ * @cal_view: an #ECalendarView
+ * @all_day: Whether create all day event or not.
+ * @meeting: This is a meeting or an appointment.
+ * @no_past_date: Don't create event in past date, use actual date instead
+ * (if %TRUE).
  *
  * Opens an event editor dialog for a new appointment. The appointment's
  * start and end times are set to the currently selected time range in
