@@ -24,10 +24,6 @@
 #include <glib/gi18n.h>
 #include <camel/camel.h>
 
-#define E_COMPOSER_POST_HEADER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_COMPOSER_POST_HEADER, EComposerPostHeaderPrivate))
-
 enum {
 	PROP_0,
 	PROP_ACCOUNT
@@ -91,6 +87,7 @@ composer_post_header_set_base_url (EComposerPostHeader *header)
 	url = camel_url_to_string (camel_url, CAMEL_URL_HIDE_ALL);
 	camel_url_free (camel_url);
 
+	g_free (header->priv->base_url);
 	header->priv->base_url = url;
 }
 
@@ -171,7 +168,7 @@ composer_post_header_dispose (GObject *object)
 {
 	EComposerPostHeaderPrivate *priv;
 
-	priv = E_COMPOSER_POST_HEADER_GET_PRIVATE (object);
+	priv = E_COMPOSER_POST_HEADER (object)->priv;
 
 	if (priv->account != NULL) {
 		g_object_unref (priv->account);
@@ -187,7 +184,7 @@ composer_post_header_finalize (GObject *object)
 {
 	EComposerPostHeaderPrivate *priv;
 
-	priv = E_COMPOSER_POST_HEADER_GET_PRIVATE (object);
+	priv = E_COMPOSER_POST_HEADER (object)->priv;
 
 	g_free (priv->base_url);
 
@@ -200,7 +197,7 @@ composer_post_header_changed (EComposerHeader *header)
 {
 	EComposerPostHeaderPrivate *priv;
 
-	priv = E_COMPOSER_POST_HEADER_GET_PRIVATE (header);
+	priv = E_COMPOSER_POST_HEADER (header)->priv;
 
 	priv->custom = TRUE;
 }
@@ -210,7 +207,7 @@ composer_post_header_clicked (EComposerHeader *header)
 {
 	EComposerPostHeaderPrivate *priv;
 
-	priv = E_COMPOSER_POST_HEADER_GET_PRIVATE (header);
+	priv = E_COMPOSER_POST_HEADER (header)->priv;
 
 	priv->custom = FALSE;
 }
@@ -248,7 +245,9 @@ e_composer_post_header_class_init (EComposerPostHeaderClass *class)
 static void
 e_composer_post_header_init (EComposerPostHeader *header)
 {
-	header->priv = E_COMPOSER_POST_HEADER_GET_PRIVATE (header);
+	header->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		header, E_TYPE_COMPOSER_POST_HEADER,
+		EComposerPostHeaderPrivate);
 }
 
 EComposerHeader *
