@@ -34,10 +34,6 @@
 
 #include <glib/gi18n.h>
 
-#define E_CONFIG_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CONFIG, EConfigPrivate))
-
 #define d(x)
 
 typedef GtkWidget * (*EConfigItemSectionFactoryFunc)(EConfig *ec, EConfigItem *, GtkWidget *parent, GtkWidget *old, gpointer data, GtkWidget **real_frame);
@@ -191,7 +187,8 @@ e_config_class_init (EConfigClass *class)
 static void
 e_config_init (EConfig *config)
 {
-	config->priv = E_CONFIG_GET_PRIVATE (config);
+	config->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		config, E_TYPE_CONFIG, EConfigPrivate);
 }
 
 /**
@@ -790,6 +787,7 @@ ec_rebuild (EConfig *emp)
 					gtk_container_set_border_width ((GtkContainer *)page, 12);
 					gtk_widget_show (page);
 					gtk_notebook_insert_page ((GtkNotebook *)book, page, w, pageno);
+					gtk_container_child_set (GTK_CONTAINER (book), page, "tab-fill", FALSE, "tab-expand", FALSE, NULL);
 					wn->frame = page;
 				}
 			} else
