@@ -29,10 +29,6 @@
 #include "mail/em-composer-utils.h"
 #include "mail/em-utils.h"
 
-#define E_MAIL_DISPLAY_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MAIL_DISPLAY, EMailDisplayPrivate))
-
 struct _EMailDisplayPrivate {
 	EMFormatHTML *formatter;
 };
@@ -172,7 +168,7 @@ mail_display_dispose (GObject *object)
 {
 	EMailDisplayPrivate *priv;
 
-	priv = E_MAIL_DISPLAY_GET_PRIVATE (object);
+	priv = E_MAIL_DISPLAY (object)->priv;
 
 	if (priv->formatter) {
 		g_object_unref (priv->formatter);
@@ -198,7 +194,7 @@ mail_display_style_set (GtkWidget *widget,
 {
 	EMailDisplayPrivate *priv;
 
-	priv = E_MAIL_DISPLAY_GET_PRIVATE (widget);
+	priv = E_MAIL_DISPLAY (widget)->priv;
 
 	/* Chain up to parent's style_set() method. */
 	GTK_WIDGET_CLASS (parent_class)->style_set (widget, previous_style);
@@ -213,7 +209,7 @@ mail_display_load_string (EWebView *web_view,
 {
 	EMailDisplayPrivate *priv;
 
-	priv = E_MAIL_DISPLAY_GET_PRIVATE (web_view);
+	priv = E_MAIL_DISPLAY (web_view)->priv;
 	g_return_if_fail (priv->formatter != NULL);
 
 	if (em_format_busy (EM_FORMAT (priv->formatter)))
@@ -232,13 +228,48 @@ mail_display_url_requested (GtkHTML *html,
 	 *     until EMFormatHTML is made asynchronous. */
 }
 
+static gboolean
+mail_display_process_mailto (EWebView *web_view, const gchar *mailto_uri)
+{
+	g_return_val_if_fail (web_view != NULL, FALSE);
+	g_return_val_if_fail (mailto_uri != NULL, FALSE);
+	g_return_val_if_fail (E_IS_MAIL_DISPLAY (web_view), FALSE);
+
+	if (g_ascii_strncasecmp (mailto_uri, "mailto:", 7) == 0) {
+		EMailDisplayPrivate *priv;
+		EMFormat *format;
+		CamelFolder *folder = NULL;
+		const gchar *folder_uri = NULL;
+		EShell *shell;
+
+		priv = E_MAIL_DISPLAY (web_view)->priv;
+		g_return_val_if_fail (priv->formatter != NULL, FALSE);
+
+		format = EM_FORMAT (priv->formatter);
+
+		if (format != NULL && format->folder != NULL)
+			folder = format->folder;
+
+		if (folder != NULL)
+			folder_uri = camel_folder_get_uri (folder);
+
+		shell = e_shell_get_default ();
+		em_utils_compose_new_message_with_mailto (
+			shell, mailto_uri, folder_uri);
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 mail_display_link_clicked (GtkHTML *html,
                            const gchar *uri)
 {
 	EMailDisplayPrivate *priv;
 
-	priv = E_MAIL_DISPLAY_GET_PRIVATE (html);
+	priv = E_MAIL_DISPLAY (html)->priv;
 	g_return_if_fail (priv->formatter != NULL);
 
 	if (g_str_has_prefix (uri, "##")) {
@@ -266,14 +297,8 @@ mail_display_link_clicked (GtkHTML *html,
 		priv->formatter->header_wrap_flags = flags;
 		em_format_queue_redraw (EM_FORMAT (priv->formatter));
 
-	} else if (g_ascii_strncasecmp (uri, "mailto:", 7) == 0) {
-		EMFormat *format = EM_FORMAT (priv->formatter);
-		CamelFolder *folder = NULL;
-
-		if (format && format->folder)
-			folder = format->folder;
-
-		em_utils_compose_new_message_with_mailto (e_shell_get_default (), uri, folder ? camel_folder_get_uri (folder) : NULL);
+	} else if (mail_display_process_mailto (E_WEB_VIEW (html), uri)) {
+		/* do nothing, function handled the "mailto:" uri already */
 	} else if (*uri == '#')
 		gtk_html_jump_to_anchor (html, uri + 1);
 
@@ -311,6 +336,7 @@ mail_display_class_init (EMailDisplayClass *class)
 
 	web_view_class = E_WEB_VIEW_CLASS (class);
 	web_view_class->load_string = mail_display_load_string;
+	web_view_class->process_mailto = mail_display_process_mailto;
 
 	html_class = GTK_HTML_CLASS (class);
 	html_class->url_requested = mail_display_url_requested;
@@ -337,7 +363,8 @@ mail_display_init (EMailDisplay *display)
 
 	web_view = E_WEB_VIEW (display);
 
-	display->priv = E_MAIL_DISPLAY_GET_PRIVATE (display);
+	display->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		display, E_TYPE_MAIL_DISPLAY, EMailDisplayPrivate);
 
 	/* EWebView's action groups are added during its instance
 	 * initialization function (like what we're in now), so it
