@@ -27,18 +27,14 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <e-util/e-util.h>
+#include <e-util/e-account-utils.h>
 
-#include "mail-config.h"
 #include "em-folder-tree.h"
 #include "em-folder-selector.h"
 #include "em-utils.h"
 
 #include "em-folder-selection-button.h"
 
-#define EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), EM_TYPE_FOLDER_SELECTION_BUTTON, EMFolderSelectionButtonPrivate))
-
 struct _EMFolderSelectionButtonPrivate {
 	EMailSession *session;
 	GtkWidget *icon;
@@ -100,7 +96,7 @@ folder_selection_button_set_contents (EMFolderSelectionButton *button)
 		return;
 	}
 
-	account = mail_config_get_account_by_source_url (uri);
+	account = e_get_account_by_source_url (uri);
 
 	if (account != NULL) {
 		gchar *tmp = folder_name;
@@ -195,7 +191,7 @@ folder_selection_button_dispose (GObject *object)
 {
 	EMFolderSelectionButtonPrivate *priv;
 
-	priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (object);
+	priv = EM_FOLDER_SELECTION_BUTTON (object)->priv;
 
 	if (priv->session != NULL) {
 		g_object_unref (priv->session);
@@ -211,7 +207,7 @@ folder_selection_button_finalize (GObject *object)
 {
 	EMFolderSelectionButtonPrivate *priv;
 
-	priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (object);
+	priv = EM_FOLDER_SELECTION_BUTTON (object)->priv;
 
 	g_list_foreach (priv->uris, (GFunc) g_free, NULL);
 	g_list_free (priv->uris);
@@ -234,7 +230,7 @@ folder_selection_button_clicked (GtkButton *button)
 	GtkSelectionMode mode;
 	gpointer parent;
 
-	priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (button);
+	priv = EM_FOLDER_SELECTION_BUTTON (button)->priv;
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (button));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
@@ -365,7 +361,9 @@ em_folder_selection_button_init (EMFolderSelectionButton *emfsb)
 {
 	GtkWidget *box;
 
-	emfsb->priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (emfsb);
+	emfsb->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		emfsb, EM_TYPE_FOLDER_SELECTION_BUTTON,
+		EMFolderSelectionButtonPrivate);
 
 	emfsb->priv->multiple_select = FALSE;
 
@@ -378,7 +376,7 @@ em_folder_selection_button_init (EMFolderSelectionButton *emfsb)
 	emfsb->priv->label = gtk_label_new ("");
 	gtk_widget_show (emfsb->priv->label);
 	gtk_label_set_justify (GTK_LABEL (emfsb->priv->label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (emfsb->priv->label), 0.0, 0.0);
+	gtk_misc_set_alignment (GTK_MISC (emfsb->priv->label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (box), emfsb->priv->label, TRUE, TRUE, 0);
 
 	gtk_widget_show (box);
