@@ -68,10 +68,6 @@
 
 #define d(x)
 
-#define EM_FOLDER_TREE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), EM_TYPE_FOLDER_TREE, EMFolderTreePrivate))
-
 struct _selected_uri {
 	gchar *key;		/* store:path or account/path */
 	gchar *uri;
@@ -395,7 +391,7 @@ folder_tree_select_func (GtkTreeSelection *selection,
 
 	tree_view = gtk_tree_selection_get_tree_view (selection);
 
-	priv = EM_FOLDER_TREE_GET_PRIVATE (tree_view);
+	priv = EM_FOLDER_TREE (tree_view)->priv;
 
 	if (selected)
 		return TRUE;
@@ -822,7 +818,7 @@ folder_tree_dispose (GObject *object)
 	EMFolderTreePrivate *priv;
 	GtkTreeModel *model;
 
-	priv = EM_FOLDER_TREE_GET_PRIVATE (object);
+	priv = EM_FOLDER_TREE (object)->priv;
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (object));
 
 	if (priv->loaded_row_id != 0) {
@@ -862,7 +858,7 @@ folder_tree_finalize (GObject *object)
 {
 	EMFolderTreePrivate *priv;
 
-	priv = EM_FOLDER_TREE_GET_PRIVATE (object);
+	priv = EM_FOLDER_TREE (object)->priv;
 
 	if (priv->select_uris != NULL) {
 		g_slist_foreach (
@@ -888,7 +884,7 @@ folder_tree_button_press_event (GtkWidget *widget,
 	GtkTreePath *path;
 	gulong handler_id;
 
-	priv = EM_FOLDER_TREE_GET_PRIVATE (widget);
+	priv = EM_FOLDER_TREE (widget)->priv;
 
 	tree_view = GTK_TREE_VIEW (widget);
 	selection = gtk_tree_view_get_selection (tree_view);
@@ -947,7 +943,7 @@ folder_tree_key_press_event (GtkWidget *widget,
 		return TRUE;
 	}
 
-	priv = EM_FOLDER_TREE_GET_PRIVATE (widget);
+	priv = EM_FOLDER_TREE (widget)->priv;
 
 	tree_view = GTK_TREE_VIEW (widget);
 	selection = gtk_tree_view_get_selection (tree_view);
@@ -981,7 +977,7 @@ folder_tree_row_activated (GtkTreeView *tree_view,
 	GtkTreeIter iter;
 	guint32 flags;
 
-	priv = EM_FOLDER_TREE_GET_PRIVATE (tree_view);
+	priv = EM_FOLDER_TREE (tree_view)->priv;
 
 	model = gtk_tree_view_get_model (tree_view);
 
@@ -1164,14 +1160,15 @@ folder_tree_class_init (EMFolderTreeClass *class)
 		G_TYPE_NONE, 1,
 		GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
-	signals[HIDDEN_KEY_EVENT] =
-		g_signal_new ("hidden-key-event",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EMFolderTreeClass, hidden_key_event),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
-			      G_TYPE_NONE, 1, GDK_TYPE_EVENT);
+	signals[HIDDEN_KEY_EVENT] = g_signal_new (
+		"hidden-key-event",
+		G_OBJECT_CLASS_TYPE (object_class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (EMFolderTreeClass, hidden_key_event),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__BOXED,
+		G_TYPE_NONE, 1,
+		GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 }
 
 static gboolean
@@ -1456,7 +1453,8 @@ folder_tree_init (EMFolderTree *folder_tree)
 
 	select_uris_table = g_hash_table_new (g_str_hash, g_str_equal);
 
-	folder_tree->priv = EM_FOLDER_TREE_GET_PRIVATE (folder_tree);
+	folder_tree->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		folder_tree, EM_TYPE_FOLDER_TREE, EMFolderTreePrivate);
 	folder_tree->priv->select_uris_table = select_uris_table;
 
 	tree_view = GTK_TREE_VIEW (folder_tree);
@@ -2426,37 +2424,33 @@ tree_autoscroll (EMFolderTree *folder_tree)
 	GtkTreeView *tree_view;
 	GdkRectangle rect;
 	GdkWindow *window;
-	gint offset, y;
-	gdouble page_size;
-	gdouble upper;
 	gdouble value;
+	gint offset, y;
 
-	/* get the y pointer position relative to the treeview */
+	/* Get the y pointer position relative to the treeview. */
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	window = gtk_tree_view_get_bin_window (tree_view);
 	gdk_window_get_pointer (window, NULL, &y, NULL);
 
-	/* rect is in coorinates relative to the scrolled window relative to the treeview */
+	/* Rect is in coorinates relative to the scrolled window,
+	 * relative to the treeview. */
 	gtk_tree_view_get_visible_rect (tree_view, &rect);
 
-	/* move y into the same coordinate system as rect */
+	/* Move y into the same coordinate system as rect. */
 	y += rect.y;
 
-	/* see if we are near the top edge */
-	if ((offset = y - (rect.y + 2 * SCROLL_EDGE_SIZE)) > 0) {
-		/* see if we are near the bottom edge */
-		if ((offset = y - (rect.y + rect.height - 2 * SCROLL_EDGE_SIZE)) < 0)
+	/* See if we are near the top edge. */
+	offset = y - (rect.y + 2 * SCROLL_EDGE_SIZE);
+	if (offset > 0) {
+		/* See if we are near the bottom edge. */
+		offset = y - (rect.y + rect.height - 2 * SCROLL_EDGE_SIZE);
+		if (offset < 0)
 			return TRUE;
 	}
 
 	adjustment = gtk_tree_view_get_vadjustment (tree_view);
-
-	page_size = gtk_adjustment_get_value (adjustment);
-	upper = gtk_adjustment_get_upper (adjustment);
 	value = gtk_adjustment_get_value (adjustment);
-
-	value = CLAMP (value + offset, 0.0, upper - page_size);
-	gtk_adjustment_set_value (adjustment, value);
+	gtk_adjustment_set_value (adjustment, MAX (value + offset, 0.0));
 
 	return TRUE;
 }
