@@ -27,9 +27,8 @@
 
 #include <libedataserver/e-flag.h>
 
-#include "shell/e-shell.h"
-#include "e-util/e-alert-activity.h"
-#include "e-util/e-alert-dialog.h"
+#include <e-util/e-alert-sink.h>
+#include <shell/e-shell-view.h>
 
 #include "mail-mt.h"
 
@@ -40,13 +39,6 @@
  *     to rework or get rid of the functions that use this. */
 const gchar *shell_builtin_backend = "mail";
 
-/* background operation status stuff */
-struct _MailMsgPrivate {
-	EActivity *activity;
-	GtkWidget *error;
-	gboolean cancelable;
-};
-
 static guint mail_msg_seq; /* sequence number of each message */
 
 /* Table of active messages.  Must hold mail_msg_lock to access. */
@@ -80,6 +72,7 @@ gpointer
 mail_msg_new (MailMsgInfo *info)
 {
 	MailMsg *msg;
+	GCancellable *cancellable;
 
 	g_mutex_lock (mail_msg_lock);
 
@@ -87,23 +80,20 @@ mail_msg_new (MailMsgInfo *info)
 	msg->info = info;
 	msg->ref_count = 1;
 	msg->seq = mail_msg_seq++;
-	msg->cancellable = camel_operation_new ();
+	msg->activity = e_activity_new ();
 
-	msg->priv = g_slice_new0 (MailMsgPrivate);
-	msg->priv->activity = e_activity_new ();
-	msg->priv->cancelable = TRUE;
+	cancellable = camel_operation_new ();
 
-	e_activity_set_percent (msg->priv->activity, 0.0);
-
-	e_activity_set_cancellable (
-		msg->priv->activity,
-		G_CANCELLABLE (msg->cancellable));
+	e_activity_set_percent (msg->activity, 0.0);
+	e_activity_set_cancellable (msg->activity, cancellable);
 
 	g_signal_connect (
-		msg->cancellable, "cancelled",
+		cancellable, "cancelled",
 		G_CALLBACK (mail_msg_cancelled),
 		GINT_TO_POINTER (msg->seq));
 
+	g_object_unref (cancellable);
+
 	g_hash_table_insert (
 		mail_msg_active_table, GINT_TO_POINTER (msg->seq), msg);
 
@@ -141,37 +131,14 @@ checkmem (gpointer p)
 static gboolean
 mail_msg_free (MailMsg *mail_msg)
 {
-	EShell *shell;
-	EShellBackend *shell_backend;
-
 	/* This is an idle callback. */
 
-	shell = e_shell_get_default ();
-	shell_backend = e_shell_get_backend_by_name (
-		shell, shell_builtin_backend);
-
-	if (mail_msg->priv->activity != NULL) {
-		e_activity_complete (mail_msg->priv->activity);
-		g_object_unref (mail_msg->priv->activity);
-	}
-
-	if (mail_msg->cancellable != NULL)
-		g_object_unref (mail_msg->cancellable);
+	if (mail_msg->activity != NULL)
+		g_object_unref (mail_msg->activity);
 
 	if (mail_msg->error != NULL)
 		g_error_free (mail_msg->error);
 
-	if (mail_msg->priv->error != NULL) {
-		EActivity *activity;
-		GtkWidget *widget;
-
-		widget = mail_msg->priv->error;
-		activity = e_alert_activity_new_warning (widget);
-		e_shell_backend_add_activity (shell_backend, activity);
-		g_object_unref (activity);
-	}
-
-	g_slice_free (MailMsgPrivate, mail_msg->priv);
 	g_slice_free1 (mail_msg->info->size, mail_msg);
 
 	return FALSE;
@@ -224,28 +191,16 @@ mail_msg_unref (gpointer msg)
 	g_idle_add ((GSourceFunc) mail_msg_free, mail_msg);
 }
 
-/* hash table of ops->dialogue of active errors */
-static GHashTable *active_errors = NULL;
-
-static void
-error_finalized (gpointer data, GObject *gone_gd)
-{
-	g_hash_table_remove (active_errors, data);
-}
-
-static void
-error_response (GtkWidget *dialog, gint button, gpointer data)
-{
-	gtk_widget_destroy (dialog);
-}
-
 void
 mail_msg_check_error (gpointer msg)
 {
-	GtkWindow *parent;
+	EShell *shell;
+	EShellView *shell_view;
+	EShellWindow *shell_window = NULL;
+	EShellContent *shell_content;
 	MailMsg *m = msg;
 	gchar *what;
-	GtkDialog *gd;
+	GList *list, *iter;
 
 #ifdef MALLOC_CHECK
 	checkmem (m);
@@ -253,45 +208,53 @@ mail_msg_check_error (gpointer msg)
 	checkmem (m->priv);
 #endif
 
-	if (m->error == NULL
-	    || g_error_matches (m->error, G_IO_ERROR, G_IO_ERROR_CANCELLED)
-	    || g_error_matches (m->error, CAMEL_FOLDER_ERROR, CAMEL_FOLDER_ERROR_INVALID_UID))
-		return;
-
-	if (active_errors == NULL)
-		active_errors = g_hash_table_new (NULL, NULL);
-
-	/* check to see if we have dialogue already running for this operation */
-	/* we key on the operation pointer, which is at least accurate enough
-	   for the operation type, although it could be on a different object. */
-	if (g_hash_table_lookup (active_errors, m->info)) {
-		g_message (
-			"Error occurred while existing dialogue active:\n%s",
-			m->error->message);
+	if (g_error_matches (m->error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+		e_activity_set_state (m->activity, E_ACTIVITY_CANCELLED);
 		return;
 	}
 
-	parent = e_shell_get_active_window (NULL);
+	e_activity_set_state (m->activity, E_ACTIVITY_COMPLETED);
 
-	if (m->info->desc
-	    && (what = m->info->desc (m))) {
-		gd = (GtkDialog *) e_alert_dialog_new_for_args (
-			parent, "mail:async-error", what,
+	if (m->error == NULL)
+		return;
+
+	/* XXX Hmm, no explanation of why this is needed.  It looks like
+	 *     a lame hack and will be removed at some point, if only to
+	 *     reintroduce whatever issue made this necessary so we can
+	 *     document it the source code this time. */
+	if (g_error_matches (m->error, CAMEL_FOLDER_ERROR, CAMEL_FOLDER_ERROR_INVALID_UID))
+		return;
+
+	shell = e_shell_get_default ();
+
+	/* Find the most recently used EShellWindow. */
+	list =  e_shell_get_watched_windows (shell);
+	for (iter = list; iter != NULL; iter = g_list_next (iter)) {
+		if (E_IS_SHELL_WINDOW (iter->data)) {
+			shell_window = E_SHELL_WINDOW (iter->data);
+			break;
+		}
+	}
+
+	/* If we can't find an EShellWindow then... well, screw it. */
+	if (shell_window == NULL)
+		return;
+
+	shell_view = e_shell_window_get_shell_view (
+		shell_window, shell_builtin_backend);
+	shell_content = e_shell_view_get_shell_content (shell_view);
+
+	if (m->info->desc && (what = m->info->desc (m))) {
+		e_alert_submit (
+			E_ALERT_SINK (shell_content),
+			"mail:async-error", what,
 			m->error->message, NULL);
 		g_free (what);
 	} else
-		gd = (GtkDialog *) e_alert_dialog_new_for_args (
-			parent, "mail:async-error-nodescribe",
+		e_alert_submit (
+			E_ALERT_SINK (shell_content),
+			"mail:async-error-nodescribe",
 			m->error->message, NULL);
-
-	g_hash_table_insert (active_errors, m->info, gd);
-	g_signal_connect(gd, "response", G_CALLBACK(error_response), m->info);
-	g_object_weak_ref (G_OBJECT (gd), error_finalized, m->info);
-	if (m->priv->cancelable)
-		m->priv->error = (GtkWidget *) gd;
-	else
-		gtk_widget_show ((GtkWidget *)gd);
-
 }
 
 void
@@ -307,8 +270,13 @@ mail_msg_cancel (guint msgid)
 
 	/* Hold a reference to the GCancellable so it doesn't finalize
 	 * itself on us between unlocking the mutex and cancelling. */
-	if (msg != NULL && !g_cancellable_is_cancelled (msg->cancellable))
-		cancellable = g_object_ref (msg->cancellable);
+	if (msg != NULL) {
+		cancellable = e_activity_get_cancellable (msg->activity);
+		if (g_cancellable_is_cancelled (cancellable))
+			cancellable = NULL;
+		else
+			g_object_ref (cancellable);
+	}
 
 	g_mutex_unlock (mail_msg_lock);
 
@@ -379,14 +347,6 @@ mail_cancel_all (void)
 	g_mutex_unlock (mail_msg_lock);
 }
 
-void
-mail_msg_set_cancelable (gpointer msg, gboolean status)
-{
-	MailMsg *mail_msg = msg;
-
-	mail_msg->priv->cancelable = status;
-}
-
 static guint idle_source_id = 0;
 G_LOCK_DEFINE_STATIC (idle_source_id);
 static GAsyncQueue *main_loop_queue = NULL;
@@ -406,13 +366,17 @@ mail_msg_idle_cb (void)
 	G_UNLOCK (idle_source_id);
 	/* check the main loop queue */
 	while ((msg = g_async_queue_try_pop (main_loop_queue)) != NULL) {
+		GCancellable *cancellable;
+
+		cancellable = e_activity_get_cancellable (msg->activity);
+
 		g_idle_add_full (
 			G_PRIORITY_DEFAULT,
 			(GSourceFunc) mail_msg_submit,
-			g_object_ref (msg->priv->activity),
+			g_object_ref (msg->activity),
 			(GDestroyNotify) g_object_unref);
 		if (msg->info->exec != NULL)
-			msg->info->exec (msg);
+			msg->info->exec (msg, cancellable, &msg->error);
 		if (msg->info->done != NULL)
 			msg->info->done (msg);
 		mail_msg_unref (msg);
@@ -431,23 +395,27 @@ mail_msg_idle_cb (void)
 static void
 mail_msg_proxy (MailMsg *msg)
 {
+	GCancellable *cancellable;
+
+	cancellable = e_activity_get_cancellable (msg->activity);
+
 	if (msg->info->desc != NULL) {
 		gchar *text = msg->info->desc (msg);
-		camel_operation_push_message (msg->cancellable, "%s", text);
+		camel_operation_push_message (cancellable, "%s", text);
 		g_free (text);
 	}
 
 	g_idle_add_full (
 		G_PRIORITY_DEFAULT,
 		(GSourceFunc) mail_msg_submit,
-		g_object_ref (msg->priv->activity),
+		g_object_ref (msg->activity),
 		(GDestroyNotify) g_object_unref);
 
 	if (msg->info->exec != NULL)
-		msg->info->exec (msg);
+		msg->info->exec (msg, cancellable, &msg->error);
 
 	if (msg->info->desc != NULL)
-		camel_operation_pop_message (msg->cancellable);
+		camel_operation_pop_message (cancellable);
 
 	g_async_queue_push (msg_reply_queue, msg);
 
@@ -560,7 +528,9 @@ struct _call_msg {
 };
 
 static void
-do_call (struct _call_msg *m)
+do_call (struct _call_msg *m,
+         GCancellable *cancellable,
+         GError **error)
 {
 	gpointer p1, *p2, *p3, *p4, *p5;
 	gint i1;
@@ -610,6 +580,11 @@ do_call (struct _call_msg *m)
 		break;
 	}
 
+	e_activity_set_state (
+		m->base.activity,
+		g_cancellable_is_cancelled (cancellable) ?
+		E_ACTIVITY_CANCELLED : E_ACTIVITY_COMPLETED);
+
 	if (m->done != NULL)
 		e_flag_set (m->done);
 }
@@ -625,6 +600,7 @@ static MailMsgInfo mail_call_info = {
 gpointer
 mail_call_main (mail_call_t type, MailMainFunc func, ...)
 {
+	GCancellable *cancellable;
 	struct _call_msg *m;
 	gpointer ret;
 	va_list ap;
@@ -636,8 +612,10 @@ mail_call_main (mail_call_t type, MailMainFunc func, ...)
 	m->func = func;
 	G_VA_COPY (m->ap, ap);
 
+	cancellable = e_activity_get_cancellable (m->base.activity);
+
 	if (mail_in_main_thread ())
-		do_call (m);
+		do_call (m, cancellable, &m->base.error);
 	else {
 		mail_msg_ref (m);
 		m->done = e_flag_new ();
