@@ -29,10 +29,6 @@
 
 #include "calendar/common/authentication.h"
 
-#define E_CAL_ATTACHMENT_HANDLER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CAL_ATTACHMENT_HANDLER, ECalAttachmentHandlerPrivate))
-
 typedef struct _ImportContext ImportContext;
 
 struct _ECalAttachmentHandlerPrivate {
@@ -83,7 +79,19 @@ attachment_handler_get_component (EAttachment *attachment)
 	camel_data_wrapper_decode_to_stream_sync (wrapper, stream, NULL, NULL);
 	g_object_unref (stream);
 
-	component = e_cal_util_parse_ics_string ((gchar *) buffer->data);
+	if (buffer->len > 0) {
+		const gchar *str;
+
+		/* ensure string being null-terminated  */
+		g_byte_array_append (buffer, (const guint8 *) "", 1);
+
+		str = (const gchar *) buffer->data;
+		while (*str && g_ascii_isspace (*str))
+			str++;
+
+		if (g_ascii_strncasecmp (str, "BEGIN:", 6) == 0)
+			component = e_cal_util_parse_ics_string (str);
+	}
 
 	g_byte_array_free (buffer, TRUE);
 
@@ -480,7 +488,9 @@ cal_attachment_handler_class_init (ECalAttachmentHandlerClass *class)
 static void
 cal_attachment_handler_init (ECalAttachmentHandler *handler)
 {
-	handler->priv = E_CAL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
+	handler->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		handler, E_TYPE_CAL_ATTACHMENT_HANDLER,
+		ECalAttachmentHandlerPrivate);
 }
 
 GType
