@@ -27,11 +27,11 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <libecal/e-cal-time-util.h>
+#include <libecal/e-cal-system-timezone.h>
 #include <libedataserver/e-categories.h>
 #include <libedataserver/e-data-server-util.h>
 #include <libedataserver/e-sexp.h>
 
-#include "e-util/e-binding.h"
 #include "e-util/e-selection.h"
 #include "e-util/e-dialog-utils.h"
 #include "e-util/e-file-utils.h"
@@ -63,10 +63,6 @@
 #include "e-cal-shell-sidebar.h"
 #include "e-cal-shell-view-actions.h"
 
-#define E_CAL_SHELL_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CAL_SHELL_VIEW, ECalShellViewPrivate))
-
 /* Shorthand, requires a variable named "shell_window". */
 #define ACTION(name) \
 	(E_SHELL_WINDOW_ACTION_##name (shell_window))
@@ -81,6 +77,7 @@
 
 /* ETable Specifications */
 #define ETSPEC_FILENAME		"e-calendar-table.etspec"
+#define CHECK_NB	5
 
 G_BEGIN_DECLS
 
@@ -114,6 +111,8 @@ struct _ECalShellViewPrivate {
 	EActivity *calendar_activity;
 	EActivity *memopad_activity;
 	EActivity *taskpad_activity;
+
+        GFileMonitor *monitors[CHECK_NB];
 };
 
 void		e_cal_shell_view_private_init
