@@ -35,10 +35,6 @@
 #include "calendar/gui/e-cal-model-memos.h"
 #include "calendar/gui/e-memo-table.h"
 
-#define E_MEMO_SHELL_CONTENT_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MEMO_SHELL_CONTENT, EMemoShellContentPrivate))
-
 #define E_MEMO_TABLE_DEFAULT_STATE \
 	"<?xml version=\"1.0\"?>" \
 	"<ETableState>" \
@@ -209,7 +205,9 @@ memo_shell_content_cursor_change_cb (EMemoShellContent *memo_shell_content,
 	e_cal_component_set_icalcomponent (
 		comp, icalcomponent_new_clone (comp_data->icalcomp));
 	e_cal_component_preview_display (
-		memo_preview, comp_data->client, comp);
+		memo_preview, comp_data->client, comp,
+		e_cal_model_get_timezone (memo_model),
+		e_cal_model_get_use_24_hour_format (memo_model));
 
 	e_cal_component_get_uid (comp, &uid);
 	g_free (memo_shell_content->priv->current_uid);
@@ -275,7 +273,7 @@ memo_shell_content_restore_state_cb (EShellWindow *shell_window,
 	GObject *object;
 	const gchar *key;
 
-	priv = E_MEMO_SHELL_CONTENT_GET_PRIVATE (shell_content);
+	priv = E_MEMO_SHELL_CONTENT (shell_content)->priv;
 
 	/* Bind GObject properties to GConf keys. */
 
@@ -365,7 +363,7 @@ memo_shell_content_dispose (GObject *object)
 {
 	EMemoShellContentPrivate *priv;
 
-	priv = E_MEMO_SHELL_CONTENT_GET_PRIVATE (object);
+	priv = E_MEMO_SHELL_CONTENT (object)->priv;
 
 	if (priv->paned != NULL) {
 		g_object_unref (priv->paned);
@@ -401,7 +399,7 @@ memo_shell_content_finalize (GObject *object)
 {
 	EMemoShellContentPrivate *priv;
 
-	priv = E_MEMO_SHELL_CONTENT_GET_PRIVATE (object);
+	priv = E_MEMO_SHELL_CONTENT (object)->priv;
 
 	g_free (priv->current_uid);
 
@@ -415,20 +413,18 @@ memo_shell_content_constructed (GObject *object)
 	EMemoShellContentPrivate *priv;
 	EShell *shell;
 	EShellView *shell_view;
-	EShellSettings *shell_settings;
 	EShellBackend *shell_backend;
 	EShellContent *shell_content;
 	EShellTaskbar *shell_taskbar;
 	EShellWindow *shell_window;
 	GalViewInstance *view_instance;
-	icaltimezone *timezone;
 	GtkTargetList *target_list;
 	GtkTargetEntry *targets;
 	GtkWidget *container;
 	GtkWidget *widget;
 	gint n_targets;
 
-	priv = E_MEMO_SHELL_CONTENT_GET_PRIVATE (object);
+	priv = E_MEMO_SHELL_CONTENT (object)->priv;
 
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (parent_class)->constructed (object);
@@ -438,15 +434,10 @@ memo_shell_content_constructed (GObject *object)
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_taskbar = e_shell_view_get_shell_taskbar (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
-
 	shell = e_shell_backend_get_shell (shell_backend);
-	shell_settings = e_shell_get_shell_settings (shell);
 
 	priv->memo_model = e_cal_model_memos_new ();
 
-	timezone = e_shell_settings_get_pointer (
-		shell_settings, "cal-timezone");
-
 	/* Build content widgets. */
 
 	container = GTK_WIDGET (object);
@@ -482,8 +473,6 @@ memo_shell_content_constructed (GObject *object)
 	container = priv->paned;
 
 	widget = e_cal_component_preview_new ();
-	e_cal_component_preview_set_default_timezone (
-		E_CAL_COMPONENT_PREVIEW (widget), timezone);
 	e_shell_configure_web_view (shell, E_WEB_VIEW (widget));
 	gtk_widget_show (widget);
 
@@ -613,7 +602,7 @@ memo_shell_content_focus_search_results (EShellContent *shell_content)
 {
 	EMemoShellContentPrivate *priv;
 
-	priv = E_MEMO_SHELL_CONTENT_GET_PRIVATE (shell_content);
+	priv = E_MEMO_SHELL_CONTENT (shell_content)->priv;
 
 	gtk_widget_grab_focus (priv->memo_table);
 }
@@ -666,8 +655,9 @@ memo_shell_content_class_init (EMemoShellContentClass *class)
 static void
 memo_shell_content_init (EMemoShellContent *memo_shell_content)
 {
-	memo_shell_content->priv =
-		E_MEMO_SHELL_CONTENT_GET_PRIVATE (memo_shell_content);
+	memo_shell_content->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		memo_shell_content, E_TYPE_MEMO_SHELL_CONTENT,
+		EMemoShellContentPrivate);
 
 	/* Postpone widget construction until we have a shell view. */
 }
