@@ -27,10 +27,6 @@
 #include "mail/e-mail-backend.h"
 #include "mail/em-composer-utils.h"
 
-#define E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MAIL_ATTACHMENT_HANDLER, EMailAttachmentHandlerPrivate))
-
 struct _EMailAttachmentHandlerPrivate {
 	EShell *shell;
 	EMailSession *session;
@@ -61,14 +57,17 @@ mail_attachment_handler_forward (GtkAction *action,
                                  EAttachmentHandler *handler)
 {
 	EMailAttachmentHandlerPrivate *priv;
+	EShellSettings *shell_settings;
 	EAttachment *attachment;
 	EAttachmentView *view;
 	CamelMimePart *mime_part;
 	CamelDataWrapper *wrapper;
+	EMailForwardStyle style;
+	const gchar *property_name;
 	GList *selected;
 
 	view = e_attachment_handler_get_view (handler);
-	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
+	priv = E_MAIL_ATTACHMENT_HANDLER (handler)->priv;
 
 	selected = e_attachment_view_get_selected_attachments (view);
 	g_return_if_fail (g_list_length (selected) == 1);
@@ -77,8 +76,12 @@ mail_attachment_handler_forward (GtkAction *action,
 	mime_part = e_attachment_get_mime_part (attachment);
 	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
 
+	property_name = "mail-forward-style";
+	shell_settings = e_shell_get_shell_settings (priv->shell);
+	style = e_shell_settings_get_int (shell_settings, property_name);
+
 	em_utils_forward_message (
-		priv->shell, CAMEL_MIME_MESSAGE (wrapper), NULL);
+		priv->shell, CAMEL_MIME_MESSAGE (wrapper), NULL, style);
 
 	g_list_foreach (selected, (GFunc) g_object_unref, NULL);
 	g_list_free (selected);
@@ -89,14 +92,17 @@ mail_attachment_handler_reply_all (GtkAction *action,
                                    EAttachmentHandler *handler)
 {
 	EMailAttachmentHandlerPrivate *priv;
+	EShellSettings *shell_settings;
 	EAttachment *attachment;
 	EAttachmentView *view;
 	CamelMimePart *mime_part;
 	CamelDataWrapper *wrapper;
+	EMailReplyStyle style;
+	const gchar *property_name;
 	GList *selected;
 
 	view = e_attachment_handler_get_view (handler);
-	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
+	priv = E_MAIL_ATTACHMENT_HANDLER (handler)->priv;
 
 	selected = e_attachment_view_get_selected_attachments (view);
 	g_return_if_fail (g_list_length (selected) == 1);
@@ -105,9 +111,16 @@ mail_attachment_handler_reply_all (GtkAction *action,
 	mime_part = e_attachment_get_mime_part (attachment);
 	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
 
+	property_name = "mail-reply-style";
+	shell_settings = e_shell_get_shell_settings (priv->shell);
+	style = e_shell_settings_get_int (shell_settings, property_name);
+
+	/* em_utils_reply_to_message() unrefs 'message', thus ref it here */
+	g_object_ref (wrapper);
+
 	em_utils_reply_to_message (
 		priv->shell, NULL, NULL, CAMEL_MIME_MESSAGE (wrapper),
-		REPLY_MODE_ALL, NULL);
+		E_MAIL_REPLY_TO_ALL, style, NULL);
 
 	g_list_foreach (selected, (GFunc) g_object_unref, NULL);
 	g_list_free (selected);
@@ -118,14 +131,17 @@ mail_attachment_handler_reply_sender (GtkAction *action,
                                       EAttachmentHandler *handler)
 {
 	EMailAttachmentHandlerPrivate *priv;
+	EShellSettings *shell_settings;
 	EAttachment *attachment;
 	EAttachmentView *view;
 	CamelMimePart *mime_part;
 	CamelDataWrapper *wrapper;
+	EMailForwardStyle style;
+	const gchar *property_name;
 	GList *selected;
 
 	view = e_attachment_handler_get_view (handler);
-	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
+	priv = E_MAIL_ATTACHMENT_HANDLER (handler)->priv;
 
 	selected = e_attachment_view_get_selected_attachments (view);
 	g_return_if_fail (g_list_length (selected) == 1);
@@ -134,9 +150,16 @@ mail_attachment_handler_reply_sender (GtkAction *action,
 	mime_part = e_attachment_get_mime_part (attachment);
 	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
 
+	property_name = "mail-reply-style";
+	shell_settings = e_shell_get_shell_settings (priv->shell);
+	style = e_shell_settings_get_int (shell_settings, property_name);
+
+	/* em_utils_reply_to_message() unrefs 'message', thus ref it here */
+	g_object_ref (wrapper);
+
 	em_utils_reply_to_message (
 		priv->shell, NULL, NULL, CAMEL_MIME_MESSAGE (wrapper),
-		REPLY_MODE_SENDER, NULL);
+		E_MAIL_REPLY_TO_SENDER, style, NULL);
 
 	g_list_foreach (selected, (GFunc) g_object_unref, NULL);
 	g_list_free (selected);
@@ -265,7 +288,7 @@ mail_attachment_handler_x_uid_list (EAttachmentView *view,
 		return;
 
 	store = e_attachment_view_get_store (view);
-	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
+	priv = E_MAIL_ATTACHMENT_HANDLER (handler)->priv;
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (view));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
@@ -432,7 +455,7 @@ mail_attachment_handler_dispose (GObject *object)
 {
 	EMailAttachmentHandlerPrivate *priv;
 
-	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (object);
+	priv = E_MAIL_ATTACHMENT_HANDLER (object)->priv;
 
 	if (priv->shell != NULL) {
 		g_object_unref (priv->shell);
@@ -462,7 +485,7 @@ mail_attachment_handler_constructed (GObject *object)
 	GError *error = NULL;
 
 	handler = E_ATTACHMENT_HANDLER (object);
-	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (object);
+	priv = E_MAIL_ATTACHMENT_HANDLER (object)->priv;
 
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (parent_class)->constructed (object);
@@ -542,7 +565,9 @@ mail_attachment_handler_class_init (EMailAttachmentHandlerClass *class)
 static void
 mail_attachment_handler_init (EMailAttachmentHandler *handler)
 {
-	handler->priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
+	handler->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		handler, E_TYPE_MAIL_ATTACHMENT_HANDLER,
+		EMailAttachmentHandlerPrivate);
 }
 
 GType
