@@ -29,7 +29,6 @@
 
 #include <glib/gi18n-lib.h>
 
-#include "e-util/e-binding.h"
 #include "widgets/misc/e-import-assistant.h"
 
 /**
@@ -45,16 +44,13 @@ void
 e_shell_configure_ui_manager (EShell *shell,
                               EUIManager *ui_manager)
 {
-	EShellSettings *shell_settings;
-
 	g_return_if_fail (E_IS_SHELL (shell));
 	g_return_if_fail (E_IS_UI_MANAGER (ui_manager));
 
-	shell_settings = e_shell_get_shell_settings (shell);
-
-	e_binding_new (
+	g_object_bind_property (
 		shell, "express-mode",
-		ui_manager, "express-mode");
+		ui_manager, "express-mode",
+		G_BINDING_SYNC_CREATE);
 }
 
 /**
@@ -69,6 +65,9 @@ void
 e_shell_configure_web_view (EShell *shell,
                             EWebView *web_view)
 {
+#if 0  /* XXX Lockdown keys have moved to gsettings-desktop-scheams,
+	*     so disable lockdown integration until we're ready for
+	*     GSettings. */
 	EShellSettings *shell_settings;
 
 	g_return_if_fail (E_IS_SHELL (shell));
@@ -77,13 +76,16 @@ e_shell_configure_web_view (EShell *shell,
 	shell_settings = e_shell_get_shell_settings (shell);
 
 #ifndef G_OS_WIN32
-	e_binding_new (
+	g_object_bind_property (
 		shell_settings, "disable-printing",
-		web_view, "disable-printing");
+		web_view, "disable-printing",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		shell_settings, "disable-save-to-disk",
-		web_view, "disable-save-to-disk");
+		web_view, "disable-save-to-disk",
+		G_BINDING_SYNC_CREATE);
+#endif
 #endif
 }
 
