@@ -242,8 +242,8 @@ e_calendar_dispose		(GObject *object)
 		cal->timeout_id = 0;
 	}
 
-	if (G_OBJECT_CLASS (e_calendar_parent_class)->dispose)
-		G_OBJECT_CLASS (e_calendar_parent_class)->dispose (object);
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (e_calendar_parent_class)->dispose (object);
 }
 
 static void
