@@ -1,22 +1,24 @@
- /* Evolution calendar - Timezone selector dialog
- *
- * Copyright (C) 2001 Ximian, Inc.
- *
- * Authors: Damon Chaplin <damon@ximian.com>
+/*
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __E_SENDOPTIONS_DIALOG_H__
@@ -25,7 +27,7 @@
 #include <gtk/gtk.h>
 #include <time.h>
 
-#define E_TYPE_SENDOPTIONS_DIALOG       (e_sendoptions_dialog_get_type ())
+#define E_TYPE_SENDOPTIONS_DIALOG       (e_send_options_dialog_get_type ())
 #define E_SENDOPTIONS_DIALOG(obj)       (G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_SENDOPTIONS_DIALOG, ESendOptionsDialog))
 #define E_SENDOPTIONS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), E_TYPE_SENDOPTIONS_DIALOG, ESendOptionsDialogClass))
 #define E_IS_SENDOPTIONS_DIALOG(obj)    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_SENDOPTIONS_DIALOG))
@@ -116,10 +118,10 @@ struct _ESendOptionsDialogClass {
 	void (* sod_response) (ESendOptionsDialog *sd, gint status);
 };
 
-GType  e_sendoptions_dialog_get_type     (void);
-ESendOptionsDialog *e_sendoptions_dialog_new (void);
-void e_sendoptions_set_need_general_options (ESendOptionsDialog *sod, gboolean needed);
-gboolean e_sendoptions_get_need_general_options (ESendOptionsDialog *sod);
-gboolean e_sendoptions_dialog_run (ESendOptionsDialog *sod, GtkWidget *parent, Item_type type);
-gboolean e_sendoptions_set_global (ESendOptionsDialog *sod, gboolean set);
+GType  e_send_options_dialog_get_type     (void);
+ESendOptionsDialog *e_send_options_dialog_new (void);
+void e_send_options_set_need_general_options (ESendOptionsDialog *sod, gboolean needed);
+gboolean e_send_options_get_need_general_options (ESendOptionsDialog *sod);
+gboolean e_send_options_dialog_run (ESendOptionsDialog *sod, GtkWidget *parent, Item_type type);
+gboolean e_send_options_set_global (ESendOptionsDialog *sod, gboolean set);
 #endif
