@@ -36,7 +36,7 @@
 #include "e-cell-vbox.h"
 #include "e-table-item.h"
 
-G_DEFINE_TYPE (ECellVbox, e_cell_vbox, E_CELL_TYPE)
+G_DEFINE_TYPE (ECellVbox, e_cell_vbox, E_TYPE_CELL)
 
 #define INDENT_AMOUNT 16
 
@@ -53,8 +53,8 @@ ecv_new_view (ECell *ecell, ETableModel *table_model, gpointer e_table_item_view
 	vbox_view->cell_view.ecell = ecell;
 	vbox_view->cell_view.e_table_model = table_model;
 	vbox_view->cell_view.e_table_item_view = e_table_item_view;
-        vbox_view->cell_view.kill_view_cb = NULL;
-        vbox_view->cell_view.kill_view_cb_data = NULL;
+	vbox_view->cell_view.kill_view_cb = NULL;
+	vbox_view->cell_view.kill_view_cb_data = NULL;
 
 	/* create our subcell view */
 	vbox_view->subcell_view_count = ecv->subcell_count;
@@ -78,11 +78,11 @@ ecv_kill_view (ECellView *ecv)
 	ECellVboxView *vbox_view = (ECellVboxView *) ecv;
 	gint i;
 
-        if (vbox_view->cell_view.kill_view_cb)
+	if (vbox_view->cell_view.kill_view_cb)
 		(vbox_view->cell_view.kill_view_cb)(ecv, vbox_view->cell_view.kill_view_cb_data);
 
-        if (vbox_view->cell_view.kill_view_cb_data)
-            g_list_free (vbox_view->cell_view.kill_view_cb_data);
+	if (vbox_view->cell_view.kill_view_cb_data)
+	    g_list_free (vbox_view->cell_view.kill_view_cb_data);
 
 	/* kill our subcell view */
 	for (i = 0; i < vbox_view->subcell_view_count; i++)
@@ -131,9 +131,16 @@ ecv_unrealize (ECellView *ecv)
  * ECell::draw method
  */
 static void
-ecv_draw (ECellView *ecell_view, GdkDrawable *drawable,
-	  gint model_col, gint view_col, gint row, ECellFlags flags,
-	  gint x1, gint y1, gint x2, gint y2)
+ecv_draw (ECellView *ecell_view,
+          cairo_t *cr,
+          gint model_col,
+          gint view_col,
+          gint row,
+          ECellFlags flags,
+          gint x1,
+          gint y1,
+          gint x2,
+          gint y2)
 {
 	ECellVboxView *vbox_view = (ECellVboxView *)ecell_view;
 
@@ -143,12 +150,20 @@ ecv_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	for (i = 0; i < vbox_view->subcell_view_count; i++) {
 		/* Now cause our subcells to draw their contents,
 		   shifted by subcell_offset pixels */
-		gint height = e_cell_height (vbox_view->subcell_views[i], vbox_view->model_cols[i], view_col, row);
-		e_cell_draw (vbox_view->subcell_views[i], drawable,
-			     vbox_view->model_cols[i], view_col, row, flags,
-			     x1, y1 + subcell_offset, x2, y1 + subcell_offset + height);
+		gint height;
 
-		subcell_offset += e_cell_height (vbox_view->subcell_views[i], vbox_view->model_cols[i], view_col, row);
+		height = e_cell_height (
+			vbox_view->subcell_views[i],
+			vbox_view->model_cols[i], view_col, row);
+		e_cell_draw (
+			vbox_view->subcell_views[i], cr,
+			vbox_view->model_cols[i], view_col, row, flags,
+			x1, y1 + subcell_offset, x2,
+			y1 + subcell_offset + height);
+
+		subcell_offset += e_cell_height (
+			vbox_view->subcell_views[i],
+			vbox_view->model_cols[i], view_col, row);
 	}
 }
 
@@ -252,10 +267,10 @@ ecv_finalize (GObject *object)
 }
 
 static void
-e_cell_vbox_class_init (ECellVboxClass *klass)
+e_cell_vbox_class_init (ECellVboxClass *class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	ECellClass *ecc = E_CELL_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	ECellClass *ecc = E_CELL_CLASS (class);
 
 	object_class->dispose = ecv_dispose;
 	object_class->finalize = ecv_finalize;
@@ -269,7 +284,7 @@ e_cell_vbox_class_init (ECellVboxClass *klass)
 	ecc->height           = ecv_height;
 	ecc->max_width        = ecv_max_width;
 
-	gal_a11y_e_cell_registry_add_cell_type (NULL, E_CELL_VBOX_TYPE, gal_a11y_e_cell_vbox_new);
+	gal_a11y_e_cell_registry_add_cell_type (NULL, E_TYPE_CELL_VBOX, gal_a11y_e_cell_vbox_new);
 }
 
 static void
@@ -291,9 +306,7 @@ e_cell_vbox_init (ECellVbox *ecv)
 ECell *
 e_cell_vbox_new (void)
 {
-	ECellVbox *ecv = g_object_new (E_CELL_VBOX_TYPE, NULL);
-
-	return (ECell *) ecv;
+	return g_object_new (E_TYPE_CELL_VBOX, NULL);
 }
 
 void
